<?php

/***************************************************************************
 *                            lang_admin.php [romn]
 *                              -------------------
 *     begin                : Sep 7 2002
 *     last update          : Dec 31, 2004
 *     language version     : 6.0
 *     copyright            : Romanian phpBB online community
 *     website              : http://www.phpbb.ro
 *     copyright 1          : (C) Daniel Tnasie
 *     email     1          : danielt@phpbb.ro
 *     copyright 2          : (C) Bogdan Toma
 *     email     2          : bogdan@phpbb.ro
 *
 *     $Id: lang_admin.php,v 1.35.2.2 2002/05/12 15:33:28 psotfx Exp $
 *
 ****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

//
// Format is same as lang_main
//

//
// Modules, this replaces the keys used
// in the modules[][] arrays in each module file
//

$lang['ENCODING'] = 'iso-8859-2';
$lang['DIRECTION'] = 'ltr';
$lang['LEFT'] = 'stnga';
$lang['RIGHT'] = 'dreapta';
$lang['DATE_FORMAT'] =  'd/M/Y'; // This should be changed to the default date format for your language, php date() format

$lang['General'] = 'Administrare general';
$lang['Users'] = 'Administrare utilizatori';
$lang['Groups'] = 'Administrare grupuri';
$lang['Forums'] = 'Administrare forumuri';
$lang['Styles'] = 'Administrare stiluri';

$lang['Configuration'] = 'Configurare general';
$lang['Permissions'] = 'Permisiuni';
$lang['Manage'] = 'Management';
$lang['Disallow'] = 'Dezactivare nume';
$lang['Prune'] = 'Curire';
$lang['Mass_Email'] = 'Expediere mesaje n bloc';
$lang['Ranks'] = 'Ranguri';
$lang['Smilies'] = 'Zmbete';
$lang['Ban_Management'] = 'Control restricii';
$lang['Word_Censor'] = 'Cuvinte cenzurate';
$lang['Export'] = 'Export';
$lang['Create_new'] = 'Creeaz';
$lang['Add_new'] = 'Adaug';
$lang['Backup_DB'] = 'Salveaz baza de date';
$lang['Restore_DB'] = 'Restaureaz baza de date';



//
// Index
//
$lang['Admin'] = 'Administrare';
$lang['Not_admin'] = 'Nu suntei autorizat s administrai acest forum';
$lang['Welcome_phpBB'] = 'Bine ai venit la centrul de control al forumului phpBB';
$lang['Admin_intro'] = 'V mulumim pentru c ai ales phpBB ca soluie pentru forumul dumneavoastr. Acest ecran v ofer o privire de ansamblu a diverselor statistici ale forumului dumneavoastr. Putei reveni la aceast pagin folosind legtura <i>Pagina de start a administratorului</i> din partea stng. Pentru a reveni la pagina de start a forumului dumneavoastr, apsai pe logo-ul phpBB-ului aflat, de asemenea, n partea stng. Celelalte legturi din partea stng v permit s controlai orice aspect al forumului, fiecare ecran va avea instruciuni care dau explicaii despre cum se folosesc instrumentele.';
$lang['Main_index'] = 'Pagina de start a forumului';
$lang['Forum_stats'] = 'Statisticile forumului';
$lang['Admin_Index'] = 'Pagina de start a administratorului';
$lang['Preview_forum'] = 'Previzualizare forum';

$lang['Click_return_admin_index'] = 'Apsai %saici%s pentru a reveni la seciunea Pagina de start a administratorului';

$lang['Statistic'] = 'Statistica';
$lang['Value'] = 'Valoarea';
$lang['Number_posts'] = 'Numrul mesajelor scrise';
$lang['Posts_per_day'] = 'Mesaje scrise pe zi';
$lang['Number_topics'] = 'Numrul subiectelor';
$lang['Topics_per_day'] = 'Subiecte pe zi';
$lang['Number_users'] = 'Numrul utilizatorilor';
$lang['Users_per_day'] = 'Utilizatori pe zi';
$lang['Board_started'] = 'Data lansrii forumului';
$lang['Avatar_dir_size'] = 'Dimensiunea directorului cu imagini asociate (Avatar)';
$lang['Database_size'] = 'Dimensiunea bazei de date';
$lang['Gzip_compression'] ='Compresia Gzip';
$lang['Not_available'] = 'Nu este disponibil()';

$lang['ON'] = 'Activ'; // This is for GZip compression
$lang['OFF'] = 'Inactiv';


//
// DB Utils
//
$lang['Database_Utilities'] = 'Instrumentele bazei de date';

$lang['Restore'] = 'Restaurare';
$lang['Backup'] = 'Salvare (Backup)';
$lang['Restore_explain'] = 'Aceasta va efectua o restaurare complet a tuturor tabelelor phpBB dintr-in fiier salvat. Dac serverul dumneavoastr suport, putei publica un fiier text compresat cu gzip i aceasta va fi decomprimat automat. <b>ATENIE:</b> Aceast procedur va rescrie orice informaie deja existent. Procesul de restaurare poate dura un timp ndelungat; v rugm nu prsii aceast pagin pn cnd restaurarea nu se termin.';
$lang['Backup_explain'] = 'Aici putei face copii de rezerv ale tuturor datelor ce in de phpBB. Dac avei i tabele adiionale n aceeai baz de date cu phpBB-ul pe care dorii s le pstrai, v rugm s introducei numele lor separate prin virgul n csua <i>Tabele Suplimentare</i> de mai jos. Dac serverul dumneavoastr suport, putei comprima fiierul cu gzip pentru a reduce dimensiunea sa nainte de a efectua operaiunea de descrcare.';

$lang['Backup_options'] = 'Opiunile de salvare (backup)';
$lang['Start_backup'] = 'Pornete operaiunea de salvare (backup)';
$lang['Full_backup'] = 'Salvare (Backup) total';
$lang['Structure_backup'] = 'Salveaz (copie de siguran) doar structura';
$lang['Data_backup'] = 'Salveaz (copie de siguran) doar datele';
$lang['Additional_tables'] = 'Tabele suplimentare';
$lang['Gzip_compress'] = 'Fiier comprimat cu Gzip';
$lang['Select_file'] = 'Selectai un fiier';
$lang['Start_Restore'] = 'Pornete operaiunea de restaurare';

$lang['Restore_success'] = 'Baza de date a fost restaurat cu succes.<br /><br />Forumul dumneavoastr ar trebui s revin la starea lui nainte ca salvarea s se fi realizat.';
$lang['Backup_download'] = 'Operaiunea de descrcare va ncepe n curnd; v rugm s ateptai pn aceasta va ncepe';
$lang['Backups_not_supported'] = 'Scuzai, dar efectuarea salvrii (backup-ului) nu este n prezent realizabil pentru sistemul dumneavoastr de baze de date';

$lang['Restore_Error_uploading'] = 'Eroare la publicarea fiierului de salvare (backup)';
$lang['Restore_Error_filename'] = 'Problem cu numele fiierului; v rugm, ncercai cu un alt fiier';
$lang['Restore_Error_decompress'] = 'Nu pot decomprima un fiier gzip; v rugm, publicai o versiune text ntreg (plain text)';
$lang['Restore_Error_no_file'] = 'Nici un fiier nu a fost publicat/ncrcat';


//
// Auth pages
//
$lang['Select_a_User'] = 'Selectai un utilizator';
$lang['Select_a_Group'] = 'Selectai un grup';
$lang['Select_a_Forum'] = 'Selectai un forum';
$lang['Auth_Control_User'] = 'Controlul permisiunilor utilizatorului';
$lang['Auth_Control_Group'] = 'Controlul permisiunilor grupului';
$lang['Auth_Control_Forum'] = 'Controlul permisiunilor forumului';
$lang['Look_up_User'] = 'Selecteaz utilizatorul';
$lang['Look_up_Group'] = 'Selecteaz grupul';
$lang['Look_up_Forum'] = 'Selecteaz forumul';

$lang['Group_auth_explain'] = 'Aici putei modifica permisiunile i starea moderatorului asociat la fiecare grup de utilizatori. Nu uitai cnd schimbai permisiunile grupului c permisiunile individuale ale utilizatorului pot s permit accesul utilizatorului la forumuri, etc. Vei fi atenionat dac va aprea aceast situaie.';
$lang['User_auth_explain'] = 'Aici putei modifica permisiunile i starea moderatorului asociat la fiecare utilizator individual. Nu uitai cnd schimbai permisiunile utilizatorului c permisiunile individuale ale grupului pot s permit accesul utilizatorului la forumuri, etc. Vei fi atenionat dac va aprea aceast situaie.';
$lang['Forum_auth_explain'] = 'Aici putei modifica nivelurile de autorizare ale fiecrui forum. Pentru a realiza acest lucru avei la dispoziie att o metod simpl ct i una avansat, metoda avansat oferind un control mai mare al fiecriei operaii din forum. Amintii-v c schimbarea nivelului de permisiuni ale forumurilor va afecta modul de realizare(finalizare) al diverselor operaiuni solicitate de ctre utilizatori.';

$lang['Simple_mode'] = 'Modul simplu';
$lang['Advanced_mode'] = 'Modul avansat';
$lang['Moderator_status'] = 'Starea moderatorului';

$lang['Allowed_Access'] = 'Acces permis';
$lang['Disallowed_Access'] = 'Acces interzis';
$lang['Is_Moderator'] = 'este moderator';
$lang['Not_Moderator'] = 'nu este moderator';

$lang['Conflict_warning'] = 'Avertizare - Conflict de autorizare';
$lang['Conflict_access_userauth'] = 'Acest utilizator are nc drepturi de acces la acest forum datorate apartenenei acestuia la grup. Putei s modificai permisiunile grupului sau s nlturai acest utilizator din grup pentru a nu mai avea depturi de acces. Grupurile care dau drepturi (i forumurile implicate) sunt afiate mai jos.';
$lang['Conflict_mod_userauth'] = 'Acest utilizator are nc drepturi de moderator la acest forum datorate apartenenei acestuia la grup. Putei s modificai permisiunile grupului sau s nlturai acest utilizator din grup pentru a nu mai avea depturi de moderator. Grupurile care dau drepturi (i forumurile implicate) sunt afiate mai jos.';
$lang['Conflict_access_groupauth'] = 'Utilizatorul(i) urmtor(i) are(au) nc drepturi de acces la acest forum datorate setrilor lui(lor) de permisiuni. Putei s modificai permisiunile utilizatorului pentru a nu mai avea drepturi de acces. Utilizatorii care dau drepturi (i forumurile implicate) sunt afiai mai jos.';
$lang['Conflict_mod_groupauth'] = 'Utilizatorul(i) urmtor(i) are(au) nc drepturi de acces la acest forum datorate setrilor lui(lor) de permisiuni. Putei s modificai permisiunile utilizatorului pentru a nu mai avea drepturi de moderator. Utilizatorii care dau drepturi (i forumurile implicate) sunt afiai mai jos.';

$lang['Public'] = 'Public';
$lang['Private'] = 'Privat';
$lang['Registered'] = 'nregistrat';
$lang['Administrators'] = 'Administratori';
$lang['Hidden'] = 'Ascuns';

// These are displayed in the drop down boxes for advanced
// mode forum auth, try and keep them short!
$lang['Forum_ALL'] = 'TOI';
$lang['Forum_REG'] = 'NREG';
$lang['Forum_PRIVATE'] = 'PRIVAT';
$lang['Forum_MOD'] = 'MOD';
$lang['Forum_ADMIN'] = 'ADMIN';

$lang['View'] = 'Vizualizare';
$lang['Read'] = 'Citire';
$lang['Post'] = 'Scriere';
$lang['Reply'] = 'Rspunde';
$lang['Edit'] = 'Modific';
$lang['Delete'] = 'terge';
$lang['Sticky'] = 'Important';
$lang['Announce'] = 'Anun';
$lang['Vote'] = 'Vot';
$lang['Pollcreate'] = 'Creare sondaj';

$lang['Permissions'] = 'Permisiuni';
$lang['Simple_Permission'] = 'Permisiune simpl';

$lang['User_Level'] = 'Nivelul utilizatorului';
$lang['Auth_User'] = 'Utilizator';
$lang['Auth_Admin'] = 'Administrator';
$lang['Group_memberships'] = 'Membru al grupurilor';
$lang['Usergroup_members'] = 'Acest grup conine urmtorii membrii';

$lang['Forum_auth_updated'] = 'Permisiunile forumului au fost actualizate';
$lang['User_auth_updated'] = 'Permisiunile utilizatorului au fost actualizate';
$lang['Group_auth_updated'] = 'Permisiunile grupului au fost actualizate';

$lang['Auth_updated'] = 'Permisiunile au fost actualizate';
$lang['Click_return_userauth'] = 'Apsai %saici%s pentru a reveni la seciunea Controlul permisiunilor utilizatorului';
$lang['Click_return_groupauth'] = 'Apsai %saici%s pentru a reveni la seciunea Controlul permisiunilor grupului';
$lang['Click_return_forumauth'] = 'Apsai %saici%s pentru a reveni la seciunea Controlul permisiunilor forumului';


//
// Banning
//
$lang['Ban_control'] = 'Controlul interdiciilor';
$lang['Ban_explain'] = 'Aici putei s controlai interdiciile utilizatorilor. Putei obine acest lucru interzicnd una sau mai multe din elementele caracteristice unui utilizator: denumire utilizator, mulimea adreselor IP sau numele host-urilor. Aceste metode mpiedic un utilizator s nu ajung n pagina de nceput a forumului. Pentru a mpiedica un utilizator s se nregistreze sub un alt nume de utilizator putei specifica o adres de mail interzis. Reinei c o singur adres de mail interzis nu-l va mpiedeca pe utilizatorul n cauz s intre sau s scrie n forumul dumneavoastr; ar trebui s folosii prima din cele dou metode.';
$lang['Ban_explain_warn'] = 'Reinei c introducerea unei mulimi de adrese IP nseamn c toate adresele dintre nceputul i sfritul mulimii au fost adugate la lista interzis. Pentru a reduce numrul de adrese adugate la baza de date se pot folosi <i>wildcard</i>-urile unde este cazul. Dac chiar trebuie s introducei o plaj de valori, ncercai s o pstrai ct mai mic sau mai bine reinei doar adresele specifice.';

$lang['Select_username'] = 'Selectai un nume de utilizator';
$lang['Select_ip'] = 'Selectai un IP';
$lang['Select_email'] = 'Selectai o adres de email';

$lang['Ban_username'] = 'Interzicei unul sau mai muli utilizatori';
$lang['Ban_username_explain'] = 'Putei interzice mai muli utilizatori ntr-un singur pas folosind combinaii potrivite ale mouse-ului (n browser) i tastaturii calculatorului dumneavoastr';

$lang['Ban_IP'] = 'Interzicei una sau mai multe adrese IP sau nume de host-uri';
$lang['IP_hostname'] = 'Adrese IP sau nume de host-uri';
$lang['Ban_IP_explain'] = 'Pentru a specifica mai multe IP-uri diferite sau nume de host-uri trebuie s le separai prin virgul. Pentru a specifica o mulime de adrese IP, separai nceputul i sfritul mulimii cu o liniu de unire (-); ca s specificai caracterul <i>wildcard</i> folosii *';

$lang['Ban_email'] = 'Interzicei una sau mai multe adrese de email';
$lang['Ban_email_explain'] = 'Pentru a specifica mai multe adrese de email folosii separatorul virgul. Ca s specificai un utilizator cu ajutorul <i>wildcard</i>-ului folosii *, de exemplu *@hotmail.com';

$lang['Unban_username'] = 'Deblocarea utilizatorilor';
$lang['Unban_username_explain'] = 'Putei s deblocai mai muli utilizatori ntr-un singur pas folosind combinaii potrivite ale mouse-ului (n browser) i tastaturii calculatorului dumneavoastr';

$lang['Unban_IP'] = 'Deblocarea adreselor IP';
$lang['Unban_IP_explain'] = 'Putei s deblocai mai multe adrese IP ntr-un singur pas folosind combinaii potrivite ale mouse-ului (n browser) i tastaturii calculatorului dumneavoastr';

$lang['Unban_email'] = 'Deblocarea adreselor email';
$lang['Unban_email_explain'] = 'Putei s deblocai mai multe adrese email ntr-un singur pas folosind combinaii potrivite ale mouse-ului (n browser) i tastaturii calculatorului dumneavoastr';

$lang['No_banned_users'] = 'Nu este nici un utilizator interzis';
$lang['No_banned_ip'] = 'Nu este nici o adres IP interzis';
$lang['No_banned_email'] = 'Nu este nici o adres de email interzis';

$lang['Ban_update_sucessful'] = 'Lista restriciilor a fost actualizat cu succes';
$lang['Click_return_banadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Control Restricii';


//
// Configuration
//
$lang['General_Config'] = 'Configurare general';
$lang['Config_explain'] = 'Formularul de mai jos v permite s personalizai toate opiunile generale ale forumului. Pentru configurarea utilizatorilor i forumurilor folosii legturile specifice aflate n partea stng.';

$lang['Click_return_config'] = 'Apsai %saici%s pentru a reveni la seciunea Configurare general';

$lang['General_settings'] = 'Setrile generale ale forumului';
$lang['Server_name'] = 'Numele domeniului';
$lang['Server_name_explain'] = 'Numele domeniului acestui forum ruleaz din';
$lang['Script_path'] = 'Calea script-ului';
$lang['Script_path_explain'] = 'Calea unde phpBB2 este localizat relativ la numele domeniului';
$lang['Server_port'] = 'Port-ul serverului';
$lang['Server_port_explain'] = 'Port-ul pe care serverul dumneavoastr ruleaz este de obicei 80 (numai dac nu a fost schimbat)';
$lang['Site_name'] = 'Numele site-ului';
$lang['Site_desc'] = 'Descrierea site-ului';
$lang['Board_disable'] = 'Forum dezactivat';
$lang['Board_disable_explain'] = 'Aceast aciune va face forumul indisponibil utilizatorilor. Nu nchidei sesiunea curent cnd dezactivai forumul, altfel nu vei mai fi capabil s v autentificai din nou!';
$lang['Acct_activation'] = 'Validarea contului activat de';
$lang['Acc_None'] = 'Nimeni'; // These three entries are the type of activation
$lang['Acc_User'] = 'Utilizator';
$lang['Acc_Admin'] = 'Administrator';

$lang['Abilities_settings'] = 'Configurrile de baz ale utilizatorilor i forumurilor';
$lang['Max_poll_options'] = 'Numrul maxim al opiunilor chestionarului';
$lang['Flood_Interval'] = 'Interval de flood';
$lang['Flood_Interval_explain'] = 'Numrul de secunde pe care un utilzator trebuie s-l atepte ntre publicri';
$lang['Board_email_form'] = 'Trimite mesaj la utilizator via forum';
$lang['Board_email_form_explain'] = 'Utilizatorii pot trimit mesaje unii la ali prin acest forum';
$lang['Topics_per_page'] = 'Subiecte pe pagin';
$lang['Posts_per_page'] = 'Mesaje pe pagin';
$lang['Hot_threshold'] = 'Mesaje pentru statutul popular';
$lang['Default_style'] = 'Stilul standard';
$lang['Override_style'] = 'Suprascrie stilul utilizatorului';
$lang['Override_style_explain'] = 'nlocuirea sitului utilizatorilor cu cel standard';
$lang['Default_language'] = 'Limba standard';
$lang['Date_format'] = 'Formatul datei';
$lang['System_timezone'] = 'Timpul zonal al sistemului';
$lang['Enable_gzip'] = 'Activare compresie GZip';
$lang['Enable_prune'] = 'Activare curire forum';
$lang['Allow_HTML'] = 'Permite HTML';
$lang['Allow_BBCode'] = 'Permite cod BB';
$lang['Allowed_tags'] = 'Permite balize (tag-uri) HTML';
$lang['Allowed_tags_explain'] = 'Separ balizele (tag-urile) cu virgule';
$lang['Allow_smilies'] = 'Permite zmbete';
$lang['Smilies_path'] = 'Calea unde se pstreaz zmbetele';
$lang['Smilies_path_explain'] = 'Calea aflat n directorul dumneavoastr phpBB , de exemplu. imagini/zmbete';
$lang['Allow_sig'] = 'Permite semnturi';
$lang['Max_sig_length'] = 'Lungimea maxim a semnturii';
$lang['Max_sig_length_explain'] = 'Numrul maxim de caractere aflate n semntura utilizatorului';
$lang['Allow_name_change'] = 'Permite schimbarea numelui de utilizator';

$lang['Avatar_settings'] = 'Configurri pentru imagini asociate (Avatar)';
$lang['Allow_local'] = 'Permite galerie de imagini asociate';
$lang['Allow_remote'] = 'Permite imagini asociate la distan';
$lang['Allow_remote_explain'] = 'Imaginile asociate sunt specificate cu o legtur la alt site web';
$lang['Allow_upload'] = 'Permite ncrcarea imaginii asociate';
$lang['Max_filesize'] = 'Dimensiunea maxim a fiierului ce conine imaginea asociat';
$lang['Max_filesize_explain'] = 'Pentru fiierele ce conin imaginile asociate ncrcate';
$lang['Max_avatar_size'] = 'Dimensiunea maxim a imaginii asociate';
$lang['Max_avatar_size_explain'] = '(nlime x Lime n pixeli)';
$lang['Avatar_storage_path'] = 'Calea de pstrare a imaginilor asociate';
$lang['Avatar_storage_path_explain'] = 'Calea aflat n directorul dumneavoastr phpBB, de exemplu. imagini/avatar';
$lang['Avatar_gallery_path'] = 'Calea de pstrare a galeriilor cu imagini asociate';
$lang['Avatar_gallery_path_explain'] = 'Calea aflat n directorul dumneavoastr phpBB, de exemplu. imagini/avatar/galerie';

$lang['COPPA_settings'] = 'Configurrile COPPA';
$lang['COPPA_fax'] = 'Numrul de fax';
$lang['COPPA_mail'] = 'Adresa potal COPPA';
$lang['COPPA_mail_explain'] = 'Aceasta este adresa potal unde prinii vor trimite formularele de nregistrare COPPA';

$lang['Email_settings'] = 'Configurrile de email';
$lang['Admin_email'] = 'Adresa de email a administratorului';
$lang['Email_sig'] = 'Semntura din email';
$lang['Email_sig_explain'] = 'Acest text va fi ataat la toate mesajele pe care forumul le trimite';
$lang['Use_SMTP'] = 'Folosii serverul SMTP pentru email';
$lang['Use_SMTP_explain'] = 'Specificai da dac dorii sau avei nevoie s trimitei mesaje printr-un alt server n loc s folosii funcia local de mesagerie';
$lang['SMTP_server'] = 'Adresa serverului SMTP';
$lang['SMTP_username'] = 'Numele de utilizator SMTP';
$lang['SMTP_username_explain'] = 'Introducei numele de utilizator doar dac serverul dumneavoastr SMTP necesit aceast specificare';
$lang['SMTP_password'] = 'Parola SMTP';
$lang['SMTP_password_explain'] = 'Introducei parola doar dac serverul dumneavoastr SMTP necesit aceast specificare';

$lang['Disable_privmsg'] = 'Mesagerie privat';
$lang['Inbox_limits'] = 'Numrul maxim al mesajelor n Cutia cu mesaje (Inbox)';
$lang['Sentbox_limits'] = 'Numrul maxim al mesajelor n Cutia cu mesaje trimise (Sentbox)';
$lang['Savebox_limits'] = 'Numrul maxim al mesajelor n Cutia cu mesaje salvate (Savebox)';

$lang['Cookie_settings'] = 'Configurrile pentru cookie';
$lang['Cookie_settings_explain'] = 'Aceste detalii definesc cum sunt cookie-urile trimise ctre browser-ele utilizatorilor. n cele mai multe cazuri valorile standard pentru setrile cookie-urilor ar trebui s fie suficiente dar dac trebuie s le schimbai avei mare grij, setrile incorecte pot mpiedica utilizatorii s se autentifice';
$lang['Cookie_domain'] = 'Domeniul pentru cookie';
$lang['Cookie_name'] = 'Numele pentru cookie';
$lang['Cookie_path'] = 'Calea pentru cookie';
$lang['Cookie_secure'] = 'Securizare cookie';
$lang['Cookie_secure_explain'] = 'Dac serverul dumneavoastr ruleaz via SSL, selectai <i>Activat</i> altfel selectai <i>Dezactivat</i>';
$lang['Session_length'] = 'Durata sesiunii [ secunde ]';


// Visual Confirmation
$lang['Visual_confirm'] = 'Activeaz Confirmarea Vizual';
$lang['Visual_confirm_explain'] = 'Necesit introducerea unui cod vizual definit ca o imagine la nregistrare.';


//
// Forum Management
//
$lang['Forum_admin'] = 'Administrare forumuri';
$lang['Forum_admin_explain'] = 'n aceast seciune putei aduga, terge, modifica, reordona i resincroniza categoriile i forumurile.';
$lang['Edit_forum'] = 'Modificare forum';
$lang['Create_forum'] = 'Creaz un forum nou';
$lang['Create_category'] = 'Creaz o categorie nou';
$lang['Remove'] = 'terge';
$lang['Action'] = 'Aciune';
$lang['Update_order'] = 'Actualizeaz ordinea';
$lang['Config_updated'] = 'Configurrile la forum au fost actualizate cu succes';
$lang['Edit'] = 'Modific';
$lang['Delete'] = 'terge';
$lang['Move_up'] = 'Mut mai sus';
$lang['Move_down'] = 'Mut mai jos';
$lang['Resync'] = 'Resincronizare';
$lang['No_mode'] = 'Nici un mod nu a fost specificat';
$lang['Forum_edit_delete_explain'] = 'Formularul de mai jos v permite s personalizai toate opiunile generale ale forumului. Pentru configurarea utilizatorilor i forumurilor folosii legturile specifice aflate n partea stng.';

$lang['Move_contents'] = 'Mut tot coninutul';
$lang['Forum_delete'] = 'tergere forum';
$lang['Forum_delete_explain'] = 'Formularul de mai jos v permite s tergei un forum (sau o categorie) i s decidei unde dorii s plasai toate subiectele (sau forumurile) pe care le conine.';

$lang['Status_locked'] = 'nchis';
$lang['Status_unlocked'] = 'Deschis';
$lang['Forum_settings'] = 'Configurrile generale ale forumului';
$lang['Forum_name'] = 'Numele forumului';
$lang['Forum_desc'] = 'Descriere';
$lang['Forum_status'] = 'Starea forumului';
$lang['Forum_pruning'] = 'Autocurare';

$lang['prune_freq'] = 'Verific vrsta subiectelor la fiecare';
$lang['prune_days'] = 'terge subiectele la care nu s-au scris rspunsuri de';
$lang['Set_prune_data'] = 'Ai selectat opiunea autocurire pentru acest forum dar nu ai specificat o frecven sau un numr de zile al intervalului pentru acest proces. V rugm revenii i specificai aceste valori';

$lang['Move_and_Delete'] = 'Mut i terge';

$lang['Delete_all_posts'] = 'terge toate mesajele';
$lang['Nowhere_to_move'] = 'Nu muta mesajele';

$lang['Edit_Category'] = 'Modificare categorie';
$lang['Edit_Category_explain'] = 'Putei folosi acest forumlar pentru a modifica numele categoriilor.';

$lang['Forums_updated'] = 'Informaiile despre forumuri i categorii au fost actualizate cu succes';

$lang['Must_delete_forums'] = 'Trebuie s tergei toate forumurile nainte ca s tergei aceast categorie';

$lang['Click_return_forumadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrare forumuri';


//
// Smiley Management
//
$lang['smiley_title'] = 'Administrare zmbete';
$lang['smile_desc'] = 'Din aceast pagin putei aduga, terge i modifica zmbetele sau emoiile asociate pe care utilizatorii dumneavoastr le pot folosi cnd scriu mesaje sau cnd trimit mesaje private.';

$lang['smiley_config'] = 'Configurare zmbete';
$lang['smiley_code'] = 'Cod zmbet';
$lang['smiley_url'] = 'Fiierul imagine al zmbetului';
$lang['smiley_emot'] = 'Emoia asociat';
$lang['smile_add'] = 'Adugai un zmbet nou';
$lang['Smile'] = 'Zmbet';
$lang['Emotion'] = 'Emoia asociat';

$lang['Select_pak'] = 'Selectai un fiier de tip Pack (.pak)';
$lang['replace_existing'] = 'nlocuii zmbetele existente';
$lang['keep_existing'] = 'Pstrai zmbetele existente';
$lang['smiley_import_inst'] = 'Ar trebui s decomprimai pachetul cu iconie i s ncrcai toate fiierele n directorul cu zmbete specificat la instalare. Apoi selectai informaiile corecte n acest formular ca s importai pachetul cu zmbete.';
$lang['smiley_import'] = 'Importai zmbetele';
$lang['choose_smile_pak'] = 'Selectai un fiier pachet cu zmbete de tip .pak';
$lang['import'] = 'Importai zmbete';
$lang['smile_conflicts'] = 'Ce ar trebui s fie fcut n caz de conflicte';
$lang['del_existing_smileys'] = 'tergei zmbetele existente nainte de import';
$lang['import_smile_pack'] = 'Importai pachetul cu zmbete';
$lang['export_smile_pack'] = 'Creai pachetul cu zmbete';
$lang['export_smiles'] = 'Ca s creai un pachet cu zmbete din zmbetele instalate, apsai %saici%s ca s descrcai fiierul cu zmbete .pak. Numii acest fiier cum dorii dar asigurai-v c ai pstrat fiierului extensia .pak. Apoi creai un fieier arhivat coninnd toate imaginile zmbete ale dumneavoastr plus acest fiier .pak.';

$lang['smiley_add_success'] = 'Zmbetul a fost adugat cu succes';
$lang['smiley_edit_success'] = 'Zmbetul a fost actualizat cu succes';
$lang['smiley_import_success'] = 'Pachetul cu zmbete a fost importat cu succes!';
$lang['smiley_del_success'] = 'Zmbetul a fost ters cu succes';
$lang['Click_return_smileadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrare zmbete';


//
// User Management
//
$lang['User_admin'] = 'Administrare utilizatori';
$lang['User_admin_explain'] = 'Aici putei schimba informaiile despre utilizatorii dumneavoastr i opiunile specifice. Ca s modificai drepturile utilizatorilor, folosii drepturile din sistem ale utilizatorilor i grupurilor.';

$lang['Look_up_user'] = 'Selecteaz utilizatorul';

$lang['Admin_user_fail'] = 'Nu se poate actualiza profilul utilizatorului.';
$lang['Admin_user_updated'] = 'Profilul utilizatorului a fost actualizat cu succes.';
$lang['Click_return_useradmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrare utilizatori';

$lang['User_delete'] = 'tergei acest utilizator';
$lang['User_delete_explain'] = 'Apsai aici pentru a terge acest utilizator, aceast operaie este ireversibil.';
$lang['User_deleted'] = 'Utilizatorul a fost ters cu succes.';

$lang['User_status'] = 'Utilizatorul este activ';
$lang['User_allowpm'] = 'Poate trimite mesaje private';
$lang['User_allowavatar'] = 'Poate folosi imagini asociate';

$lang['Admin_avatar_explain'] = 'Aici putei vizualiza i terge imaginea asociat a utilizatorului.';

$lang['User_special'] = 'Cmpuri speciale doar pentru administrator';
$lang['User_special_explain'] = 'Aceste cmpuri nu pot fi modificate de ctre utilizatori. Aici putei s specificai stadiul lor i alte opiuni care nu sunt oferite utilizatorilor.';


//
// Group Management
//
$lang['Group_administration'] = 'Administrarea grupurilor';
$lang['Group_admin_explain'] = 'Din aceast seciune putei administra toate grupurile cu utilizatori ale dumneavoastr, putei terge, crea i modifica grupurile existente. Putei alege moderatorii, schimba n deschis/nchis statutul grupului i specifica numele i descrierea grupului';
$lang['Error_updating_groups'] = 'A fost o eroare n timpul actualizrii grupurilor';
$lang['Updated_group'] = 'Grupul a fost actualizat cu succes';
$lang['Added_new_group'] = 'Noul grup a fost creat cu succes';
$lang['Deleted_group'] = 'Grupul a fost ters cu succes';
$lang['New_group'] = 'Creaz un grup nou';
$lang['Edit_group'] = 'Modific grupul';
$lang['group_name'] = 'Numele grupului';
$lang['group_description'] = 'Descrierea grupului';
$lang['group_moderator'] = 'Moderatorul grupului';
$lang['group_status'] = 'Statutul grupului';
$lang['group_open'] = 'Grup deschis';
$lang['group_closed'] = 'Grup nchis';
$lang['group_hidden'] = 'Grup ascuns';
$lang['group_delete'] = 'terg grupul';
$lang['group_delete_check'] = 'Vreau s terg acest grup';
$lang['submit_group_changes'] = 'Efectueaz modificrile';
$lang['reset_group_changes'] = 'Reseteaz modificrile';
$lang['No_group_name'] = 'Trebuie s specificai un nume pentru acest grup';
$lang['No_group_moderator'] = 'Trebuie s specificai un moderator pentru acest grup';
$lang['No_group_mode'] = 'Trebuie s specificai un mod (deschis/nchis) pentru acest grup';
$lang['No_group_action'] = 'Nici o aciune nu a fost specificat';
$lang['delete_group_moderator'] = 'Dorii s tergei moderatorul vechi al grupului?';
$lang['delete_moderator_explain'] = 'Dac schimbai moderatorul grupului, bifai aceast csu ca s tergei vechiul moderator al grupului din grup. Altfel, nu o bifai i utilizatorul va deveni un membru normal al grupului.';
$lang['Click_return_groupsadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrarea grupurilor.';
$lang['Select_group'] = 'Selecteaz un grup';
$lang['Look_up_group'] = 'Selecteaz grupul';


//
// Prune Administration
//
$lang['Forum_Prune'] = 'Curirea forumurilor';
$lang['Forum_Prune_explain'] = 'Aceast aciune va terge orice subiect care nu a fost completat ntr-un numr de zile egal cu cel pe care l-ai specificat. Dac nu ai introdus un numr atunci toate subiectele vor fi terse. Nu vor fi terse subiecte n care sondajele nc ruleaz i nici anunurile. Aceste subiecte trebuie s le tergei manual.';
$lang['Do_Prune'] = 'Efectueaz curirea';
$lang['All_Forums'] = 'Toate forumurile';
$lang['Prune_topics_not_posted'] = 'Curirea subiectelor fr rspunsuri n multe zile';
$lang['Topics_pruned'] = 'Subiecte curite';
$lang['Posts_pruned'] = 'Mesaje curite';
$lang['Prune_success'] = 'Curirea mesajelor s-a efectuat cu succes';


//
// Word censor
//
$lang['Words_title'] = 'Administrarea cuvintelor cenzurate';
$lang['Words_explain'] = 'Din aceast seciune putei aduga, modifica i terge cuvinte care vor fi automat cenzurate n forumurile dumneavoastr. n plus, persoanelor nu le va fi permis s se nregistreze cu nume de utilizator ce conin aceste cuvinte. Wildcard-urile (*) sunt acceptate n cmpul pentru cuvinte, de exemplu *test* se va potrivi cu detestabil, test* se va potrivi cu testare, *test se va potrivi cu detest.';
$lang['Word'] = 'Cuvnt';
$lang['Edit_word_censor'] = 'Modific cuvntul cenzurat';
$lang['Replacement'] = 'nlocuire';
$lang['Add_new_word'] = 'Adaug un cuvnt nou';
$lang['Update_word'] = 'Actualizeaz cuvntul cenzurat';

$lang['Must_enter_word'] = 'Trebuie s introducei un cuvnt i nlocuirile acestuia';
$lang['No_word_selected'] = 'Nici un cuvnt nu a fost selectat pentru modificare';

$lang['Word_updated'] = 'Cuvntul cenzurat selectat a fost actualizat cu succes';
$lang['Word_added'] = 'Cuvntul cenzurat a fost adugat cu succes';
$lang['Word_removed'] = 'Cuvntul cenzurat selectat a fost ters cu succes';

$lang['Click_return_wordadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrarea cuvintelor cenzurate';


//
// Mass Email
//
$lang['Mass_email_explain'] = 'Aici putei trimite un email la toi utilizatorii dumneavoastr sau la utilizatorii dintr-un grup specific. Pentru a realiza acest lucru, un email va fi trimis la adresa de email a administratorulu cu toi destinatarii specificai n cmpul BCC. Dac trimitei email la un grup mare de oameni, v rugm s fii atent dup trimitere i nu v oprii la jumtatea paginii. Este normal ca pentru o coresponden masiv s fie nevoie de un timp mai lung astfel c vei fi notificat cnd aciunea s-a terminat';
$lang['Compose'] = 'Compune';

$lang['Recipients'] = 'Destinatari';
$lang['All_users'] = 'Toi utilizatorii';

$lang['Email_successfull'] = 'Mesajul dumneavoastr a fost trimis';
$lang['Click_return_massemail'] = 'Apsai %saici%s pentru a reveni la seciunea Coresponden masiv';


//
// Ranks admin
//
$lang['Ranks_title'] = 'Administrarea rangurilor';
$lang['Ranks_explain'] = 'Folosind acest formular putei aduga, modifica, vizualiza i terge ranguri. De asemenea, putei crea ranguri personalizate care pot fi aplicate unui utilizator via facilitii date de managementul utilizatorilor';

$lang['Add_new_rank'] = 'Adaug un rang nou';

$lang['Rank_title'] = 'Titlul rangului';
$lang['Rank_special'] = 'Seteaz ca rang special';
$lang['Rank_minimum'] = 'Numr minim de mesaje';
$lang['Rank_maximum'] = 'Numr maxim de mesaje';
$lang['Rank_image'] = 'Imaginea rangului (relativ la calea phpBB2-ului)';
$lang['Rank_image_explain'] = 'Aceasta este folosit pentru a defini o imagine mic asociat cu rangul';

$lang['Must_select_rank'] = 'Trebuie s selectai un rang';
$lang['No_assigned_rank'] = 'Nici un rang special nu a fost repartizat';

$lang['Rank_updated'] = 'Rangul a fost actualizat cu succes';
$lang['Rank_added'] = 'Rangul a fost adugat cu succes';
$lang['Rank_removed'] = 'Rangul a fost ters cu succes';
$lang['No_update_ranks'] = 'Rangul a fost ters cu succes, conturile utilizatorilor care folosesc acest rang nu au fost actualizate. Trebuie s resetai manual rangul pentru aceste conturi';

$lang['Click_return_rankadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrarea rangurilor';


//
// Disallow Username Admin
//
$lang['Disallow_control'] = 'Administrarea numelor de utilizator nepremise';
$lang['Disallow_explain'] = 'Aici putei controla numele de utilizator care nu sunt permise s fie folosite. Numele de utilizator care nu sunt permise pot conine caracterul *. Reinei c nu avei posibilitatea s specificai orice nume de utilizator care a fost deja nregistrat; trebuie mai nti s tergei acel nume i apoi s-l interzicei';

$lang['Delete_disallow'] = 'terge';
$lang['Delete_disallow_title'] = 'terge un nume de utilizator nepermis';
$lang['Delete_disallow_explain'] = 'Putei terge un nume de utilizator nepermis selectnd numele de utilizator din aceast list i apsnd butonul <i>terge</i>';

$lang['Add_disallow'] = 'Adaug';
$lang['Add_disallow_title'] = 'Adaug un nume de utilizator nepermis';
$lang['Add_disallow_explain'] = 'Putei interzice un nume de utilizator folosind caracterul wildcard * care se potrivete la orice caracter';

$lang['No_disallowed'] = 'Nici un nume de utilizator nu a fost interzis';

$lang['Disallowed_deleted'] = 'Numele de utilizator nepermis a fost ters cu succes';
$lang['Disallow_successful'] = 'Numele de utilizator nepermis a fost adugat cu succes';
$lang['Disallowed_already'] = 'Numele pe care l-ai introdus nu poate fi interzis. Ori exist deja n list, exist n lista cuvintelor cenzurate sau exist un nume de utilizator similar';

$lang['Click_return_disallowadmin'] = 'Apsai %saici%s pentru a reveni la seciunea Administrarea numelor de utilizator nepremise';


//
// Styles Admin
//
$lang['Styles_admin'] = 'Administrarea stilurilor';
$lang['Styles_explain'] = 'Folosind aceast facilitate putei aduga, terge i administra stilurile (abloanele i temele) disponibile utilizatorilor dumneavoastr';
$lang['Styles_addnew_explain'] = 'Lista urmtoare conine toate temele care sunt disponibile pentru abloanele pe care le avei. Elementele din aceast list nu au fost instalate n baza de date a phpBB-ului. Ca s instalai o tem apsai pe legtura <i>Instaleaz</i> de lng denumirea temei';

$lang['Select_template'] = 'Selectai un ablon';

$lang['Style'] = 'Stilul';
$lang['Template'] = 'ablonul';
$lang['Install'] = 'Instaleaz';
$lang['Download'] = 'Descarc';

$lang['Edit_theme'] = 'Modific tema';
$lang['Edit_theme_explain'] = 'n formularul de mai jos putei modifica configurrile pentru tema selectat';

$lang['Create_theme'] = 'Creaz tem';
$lang['Create_theme_explain'] = 'Folosii formularul de mai jos ca s creai o tem nou pentru un ablon selectat. Cnd introducei culori (pentru care trebuie s folosii notaie hexazecimal) nu trebuie s includei iniiala #, de exemplu CCCCCC este valid, #CCCCCC nu este valid';

$lang['Export_themes'] = 'Export teme';
$lang['Export_explain'] = 'n aceast seciune putei exporta teme dintr-un ablon selectat. Selectai ablonul din lista de mai jos i programul va crea un fiier de configurare a temei i ncercai s-l salvai n directorul ablonului selectat. Dac fiierul nu poate fi salvat vi se va da posibilitatea s-l descrcai. Pentru ca programul s salveze fiierul trebuie s dai drepturi de scriere pentru serverul web pe directorul ablonului selectat. Pentru mai multe informaii consultai pagina 2 din ghidul utilizatorilor phpBB.';

$lang['Theme_installed'] = 'Tema selectat a fost instalat cu succes';
$lang['Style_removed'] = 'Stilul selectat a fost ters din baza de date. Pentru a terge definitiv acest stil din sistem, trebuie s-l tergei din directorul dumneavoastr cu abloane.';
$lang['Theme_info_saved'] = 'Informaiile temei pentru ablonul curent au fost salvate. Acum trebuie s specificai permisiunile n fiierul theme_info.cfg (i dac se poate directorul ablonului selectat) la acces doar de citire';
$lang['Theme_updated'] = 'Tema selectat a fost actualizat. Acum ar trebui s exportai setrile temei noi';
$lang['Theme_created'] = 'Tem a fost creat. Acum ar trebui s exportai tema n fiierul de configurare al temei pentru pstrarea n siguran a acesteia sau s-o folosii altundeva';

$lang['Confirm_delete_style'] = 'Suntei sigur c dorii s tergei acest stil?';

$lang['Download_theme_cfg'] = 'Procedura de export nu poate scrie fiierul cu informaiile temei. Apsai butonul de mai jos ca s descrcai acest fiier. Odat ce l-ai descrcat putei s-l transferai n directorul care conine fiierele cu abloane. Putei mpacheta fiierele pentru distribuie sau s le folosii unde dorii';
$lang['No_themes'] = 'ablonul pe care l-ai selectat nu are teme ataate. Ca s creai o tem nou apsai legtura <i>Creaz tem</i> din partea stng';
$lang['No_template_dir'] = 'Nu se poate deschide directorul cu abloane. Acesta ori nu poate fi citit de ctre serverul web ori nu exist';
$lang['Cannot_remove_style'] = 'Nu putei terge stilul selectat n timp ce este acesta este stilul standard pentru forum. Schimbai stilul standard i ncercai din nou.';
$lang['Style_exists'] = 'Numele stilului pe care l-ai selectat exist deja, v rugm revenii i alegei un nume diferit.';

$lang['Click_return_styleadmin'] = 'Apsai %saici%s ca s revenii la seciunea Administrarea stilurilor';

$lang['Theme_settings'] = 'Configurrile temei';
$lang['Theme_element'] = 'Elementul temei';
$lang['Simple_name'] = 'Numele simplu';
$lang['Value'] = 'Valoarea';
$lang['Save_Settings'] = 'Salveaz configurrile';

$lang['Stylesheet'] = 'Stilul CSS';
$lang['Background_image'] = 'Imaginea fundalului';
$lang['Background_color'] = 'Culoarea fundalului';
$lang['Theme_name'] = 'Numele temei';
$lang['Link_color'] = 'Culoarea legturii';
$lang['Text_color'] = 'Culoarea textului';
$lang['VLink_color'] = 'Culoarea legturii vizitate';
$lang['ALink_color'] = 'Culoarea legturii active';
$lang['HLink_color'] = 'Culoarea legturii acoperite';
$lang['Tr_color1'] = 'Culoarea 1 a rndului din tabel';
$lang['Tr_color2'] = 'Culoarea 2 a rndului din tabel';
$lang['Tr_color3'] = 'Culoarea 3 a rndului din tabel';
$lang['Tr_class1'] = 'Clasa 1 a rndului din tabel';
$lang['Tr_class2'] = 'Clasa 2 a rndului din tabel';
$lang['Tr_class3'] = 'Clasa 3 a rndului din tabel';
$lang['Th_color1'] = 'Culoarea 1 a antetului din tabel';
$lang['Th_color2'] = 'Culoarea 2 a antetului din tabel';
$lang['Th_color3'] = 'Culoarea 3 a antetului din tabel';
$lang['Th_class1'] = 'Clasa 1 a antetului din tabel';
$lang['Th_class2'] = 'Clasa 2 a antetului din tabel';
$lang['Th_class3'] = 'Clasa 3 a antetului din tabel';
$lang['Td_color1'] = 'Culoarea 1 a celulei din tabel';
$lang['Td_color2'] = 'Culoarea 2 a celulei din tabel';
$lang['Td_color3'] = 'Culoarea 3 a celulei din tabel';
$lang['Td_class1'] = 'Clasa 1 a celulei din tabel';
$lang['Td_class2'] = 'Clasa 2 a celulei din tabel';
$lang['Td_class3'] = 'Clasa 3 a celulei din tabel';
$lang['fontface1'] = 'Fontul de fa 1';
$lang['fontface2'] = 'Fontul de fa 2';
$lang['fontface3'] = 'Fontul de fa 3';
$lang['fontsize1'] = 'Dimensiunea 1 a fontului';
$lang['fontsize2'] = 'Dimensiunea 2 a fontului';
$lang['fontsize3'] = 'Dimensiunea 3 a fontului';
$lang['fontcolor1'] = 'Culoarea 1 a fontului';
$lang['fontcolor2'] = 'Culoarea 2 a fontului';
$lang['fontcolor3'] = 'Culoarea 3 a fontului';
$lang['span_class1'] = 'Clasa 1 a separatorului';
$lang['span_class2'] = 'Clasa 2 a separatorului';
$lang['span_class3'] = 'Clasa 3 a separatorului';
$lang['img_poll_size'] = 'Dimensiunea imaginii sondajului [px]';
$lang['img_pm_size'] = 'Dimensiunea statutului de mesaj privat [px]';


//
// Install Process
//
$lang['Welcome_install'] = 'Bine ai venit la procedura de instalare a forumului phpBB2';
$lang['Initial_config'] = 'Configuraia de baz';
$lang['DB_config'] = 'Configuraia bazei de date';
$lang['Admin_config'] = 'Configuraia administratorului';
$lang['continue_upgrade'] = 'Odat ce ai descrcat fiierul dumneavoastr de configurare pe calculatorul local putei folosi butonul <i>Continu actualizarea</i> de mai jos ca s trecei la urmtorul pas din actualizare. V rugm ateptai s se ncarce fiierul de configurare pn ce actualizarea  este complet.';
$lang['upgrade_submit'] = 'Continu actualizarea';

$lang['Installer_Error'] = 'O eroare a aprut n timpul instalrii';
$lang['Previous_Install'] = 'O instalare anterioar a fost detectat';
$lang['Install_db_error'] = 'O eroare a aprut n timpul actualizrii bazei de date';

$lang['Re_install'] = 'Instalarea anterioar este nc activ. <br /><br />Dac dorii s reinstalai phpBB2-ul ar trebui s apsai pe butonul Da de mai jos. V rugm s avei grij ca s nu distrugei toate datele existente, nici o copie de siguran nu va fi fcut! Numele de utilizator i parola administratorului pe care le-ai folosit s v autentificai n forum vor fi recreate dup reinstalare, nici o alt setare nu va fi pstrat. <br /><br />Gndii-v atent nainte de a apsa butonul <i>Pornete instalarea</i>!';

$lang['Inst_Step_0'] = 'V mulumim c ai ales phpBB2. Pentru a completa aceast instalare v rugm s completai detaliile de mai jos. Reinei c baza de date pe care o folosii trebuie s existe deja. Dac instalai ntr-o baz de date care folosete ODBC, de exemplu MS Access ar trebui mai nti s creai un DSN pentru aceasta nainte de a continua.';

$lang['Start_Install'] = 'Pornete instalarea';
$lang['Finish_Install'] = 'Termin instalarea';

$lang['Default_lang'] = 'Limba standard pentru forum';
$lang['DB_Host'] = 'Numele serverului gazd pentru baza de date / DSN';
$lang['DB_Name'] = 'Numele bazei dumneavoastr de date';
$lang['DB_Username'] = 'Numele de utilizator al bazei de date';
$lang['DB_Password'] = 'Parola de utilizator al bazei de date';
$lang['Database'] = 'Baza dumneavoastr de date';
$lang['Install_lang'] = 'Alegei limba pentru instalare';
$lang['dbms'] = 'Tipul bazei de date';
$lang['Table_Prefix'] = 'Prefixul pentru tabelele din baza de date';
$lang['Admin_Username'] = 'Numele de utilizator al administratorului';
$lang['Admin_Password'] = 'Parola administratorului';
$lang['Admin_Password_confirm'] = 'Parola administratorului [ Confirmai ]';

$lang['Inst_Step_2'] = 'Numele de utilizator pentru administrator a fost creat. Acum instalarea de baz este complet. Va aprea un ecran care v va permite s administrai noua dumneavoastr instalare. Asigurai-v c ai verificat detaliile seciunii Configurare general i ai efectuat orice schimbare necesar. V mulumim c ai ales phpBB2.';

$lang['Unwriteable_config'] = 'Fiierul dumneavoastr de configurare n acest moment este protejat la scriere. O copie a fiierului de configurare va fi descrcat cnd apsai butonul de mai jos. At trebui s ncrcai acest fiier n acelai director ca i phpBB2. Odat ce aceast operaiune este terminat ar trebui s v autentificai folosind numele de utilizator i parola administratorului pe care le-ai specificat n formularul anterior i s vizitai centrul de control al administratorului (o legtur va aprea la captul fiecrei pagini odat ce v-ai autentificat) ca s verificai configuraia general. V mulumim c ai ales phpBB2.';
$lang['Download_config'] = 'Descarc fiierul de configurare';

$lang['ftp_choose'] = 'Alegei metoda de descrcare';
$lang['ftp_option'] = '<br />ntruct extensiile FTP sunt activate n aceast versiune a PHP-ului, avei posibilitatea de a ncerca s plasai prin ftp fiierul de configurare la locul lui.';
$lang['ftp_instructs'] = 'Ai ales s transmitei fiierul automat prin ftp n contul care conine phpBB2-ul. V rugm introducei informaiile cerute mai jos ca s facilitai aceast proces. Calea unde este situat FTP-ul trebuie s fie calea exact via ftp la instalarea phpBB2-ului dumneavoastr ca i cum ai transmite folosind un client normal de ftp.';
$lang['ftp_info'] = 'Introducei informaiile dumneavoastr despre FTP';
$lang['Attempt_ftp'] = 'ncercare de a transfera la locul specificat fiierul de configurare prin ftp';
$lang['Send_file'] = 'Trimite doar fiierul la mine i eu voi l voi trimite manual prin ftp';
$lang['ftp_path'] = 'Calea FTP la phpBB2';
$lang['ftp_username'] = 'Numele dumneavoastr de utilizator pentru FTP';
$lang['ftp_password'] = 'Parola dumneavoastr de utilizator pentru FTP';
$lang['Transfer_config'] = 'Pornete transferul';
$lang['NoFTP_config'] = 'ncercarea de a transfera la locul specificat fiierul de configurare prin ftp a euat. V rugm s descrcai fiierul de configurare i s-l transmitei manual prin ftp la locul specificat.';

$lang['Install'] = 'Instaleaz';
$lang['Upgrade'] = 'Actualizeaz';


$lang['Install_Method'] = 'Alegei metoda de instalare';

$lang['Install_No_Ext'] = 'Configurarea php-ului pe serverul dumneavoastr nu suport tipul de baz de date pe care l-ai ales';

$lang['Install_No_PCRE'] = 'phpBB2 necesit modulul de expresii regulate compatibil Perl pentru php pe care configuraia dumneavoastr de php se pare c nu-l suport!';

//
// That's all Folks!
// -------------------------------------------------

?>